@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: __init__.py 11589 2019-05-28 17:47:23Z Lavender $
+# $Id: __init__.py 11628 2019-06-11 15:07:25Z Lavender $
 #
 # Copyright (c) 2015 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Lavender $ (last)
-# $Date: 2019-05-29 02:47:23 +0900 (週三, 29 五月 2019) $
-# $Revision: 11589 $
+# $Date: 2019-06-12 00:07:25 +0900 (週三, 12 六月 2019) $
+# $Revision: 11628 $
 
 import os
 import sys
@@ -27,7 +27,8 @@ import logging
 # Check that you don't make non-lazy gettext calls at import time.
 
 from Iuppiter.Util import extendUnique
-from Iuppiter.DjangoUtil import extendInstalledApps
+from Iuppiter.DjangoUtil import (
+    extendInstalledApps, DJANGO_VERSION, extendMiddlewareClasses)
 
 from .Version import ZEPHYRUS_VERSION
 
@@ -130,6 +131,15 @@ def attachSettings(settingsDict):
     extendInstalledApps(settingsDict, ADDING_INSTALLED_APPS,
                         key=list(keys)[-1])
     
+    #=========================================================================
+    # Middleware
+    middlewares = [
+        'Zephyrus.statistics.middleware.StatisticsMiddleware',
+    ]
+   
+    
+    extendMiddlewareClasses(settingsDict, middlewares)
+    
     #=========================================================================
     # Django CMS Ckeditor.
     DEFAULT_CKEDITOR_SETTINGS = {
