@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: models.py 11569 2019-05-21 20:41:08Z Lavender $
+# $Id: models.py 11589 2019-05-28 17:47:23Z Lavender $
 #
 # Copyright (c) 2017 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Lavender $
-# $Date: 2019-05-22 05:41:08 +0900 (週三, 22 五月 2019) $
-# $Revision: 11569 $
+# $Date: 2019-05-29 02:47:23 +0900 (週三, 29 五月 2019) $
+# $Revision: 11589 $
 
 from functools import wraps
 from django import forms
@@ -89,21 +89,6 @@ class DatePluginConfig(CMSPlugin):
         default=_settings.ZEPHYRUS_BLOG_DATE_DEFAULT_TEMPLATE,
     )
 
-class ViewCount(models.Model):
-    url = models.CharField(max_length=400, editable=False)
-    count = models.PositiveIntegerField(default=0)
-
-    @property
-    def likeCount(self):
-        return 0
-        
-class Statistics(models.Model):
-    url = models.CharField(max_length=400, editable=False)
-    viewCount = models.PositiveIntegerField(default=0)
-    likeCount = models.PositiveIntegerField(default=0)
-    commentCount = models.PositiveIntegerField(default=0)
-
-
 # modify slug field formfield
 
 # django == 1.11
