@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: build_boilerplate2.py 11497 2019-04-24 18:53:30Z Lavender $
+# $Id: build_boilerplate2.py 11589 2019-05-28 17:47:23Z Lavender $
 #
 # Copyright (c) 2017 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Lavender $
-# $Date: 2019-04-25 03:53:30 +0900 (週四, 25 四月 2019) $
-# $Revision: 11497 $
+# $Date: 2019-05-29 02:47:23 +0900 (週三, 29 五月 2019) $
+# $Revision: 11589 $
 
 import os
 import re
@@ -26,7 +26,7 @@ import collections
 import cms
 
 from lxml import etree
-from lxml.html import soupparser
+from lxml.html import soupparser, tostring
 from lxml.html.soupparser import parse
 from django.core.management.base import BaseCommand
 from django.conf import settings
@@ -158,11 +158,11 @@ class Command(BaseCommand):
                         # build placeholder
                         self.buildPlaceholder(page, name, debug=debug)
                         
-                        # deal with <head> and cms template tag
-                        self.addCMSTags(page)
-
                         # deal with file path
                         self.replaceKeyword(page, fileDict)
+                        
+                        # deal with <head> and cms template tag
+                        self.addCMSTags(page)
 
                         for tag in page.iter(tag='html'):
                             html = tag
@@ -563,7 +563,28 @@ class Command(BaseCommand):
 
     def replaceKeyword(self, page, fileDict):
         extraDict = {}
+        
         for tag in page.iter():
+            if tag.tag == 'script' or tag.tag == 'link':
+                if tag.tag == 'script':
+                    key = 'src'
+                else:
+                    key = 'href'
+                    
+                value = tag.get(key)
+                if value:
+                    value = value.replace('\\', '/')  
+                    # "./images/g2.jpg" "images/g2.jpg" 統一
+                    value = value.replace('./', '')
+                    
+                    if (not value in fileDict and 
+                        not value.lower().startswith("http") and 
+                        not value.lower().startswith("//")):
+                        tagComment = etree.Comment(tostring(tag).strip())
+                        tag.addnext(tagComment)
+                        tag.getparent().remove(tag)
+                        continue
+                    
             if tag.tag == 'script' or tag.tag == 'style':
                 if tag.text:  
                     for path in fileDict:
@@ -576,7 +597,7 @@ class Command(BaseCommand):
                                 ("./" + path), fileDict[path])
                         if path in tag.text:
                             tag.text = tag.text.replace(path, fileDict[path])
-
+            
             for name, value in tag.items():
                 if value.startswith("//") or value.startswith("http"):
                     continue
