@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: models.py 11599 2019-06-01 18:56:30Z Lavender $
+# $Id: models.py 11629 2019-06-11 17:44:34Z Lavender $
 #
 # Copyright (c) 2017 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Lavender $
-# $Date: 2019-06-02 03:56:30 +0900 (週日, 02 六月 2019) $
-# $Revision: 11599 $
+# $Date: 2019-06-12 02:44:34 +0900 (週三, 12 六月 2019) $
+# $Revision: 11629 $
 
 from django.db import models
 from django.utils.translation import ugettext_lazy as _
@@ -151,4 +151,12 @@ class FanPage(CMSPlugin):
     hideCta = models.BooleanField(_("Hide cta"), default=False)
     smallHeader = models.BooleanField(_("Small header"), default=False)
     adaptContainerWidth = models.BooleanField(
-        _("Adapt Container width"), default=False)
\ No newline at end of file
+        _("Adapt Container width"), default=False)
+
+class APIData(models.Model):
+    url = models.CharField(max_length=400, editable=False, db_index=True)
+    likeCount = models.PositiveIntegerField(
+        verbose_name=_("Like count"), default=0)
+    commentCount = models.PositiveIntegerField(
+        verbose_name=_("Comment count"), default=0)
+    updateTime = models.DateTimeField(auto_now=True)
\ No newline at end of file
