@@ -19,7 +19,7 @@ from django.db import models
 from django.utils.translation import ugettext_lazy as _
 
 class URL(models.Model):
-    url = models.CharField(max_length=400, editable=False)
+    url = models.CharField(max_length=400, editable=False, db_index=True)
     viewCount = models.PositiveIntegerField(
         verbose_name=_("View count"), default=0)
     likeCount = models.PositiveIntegerField(
