@@ -25,7 +25,6 @@ from django.utils.http import urlquote
 from Zephyrus.facebook import settings as FBSettings
 from Zephyrus.facebook import getAPIData
 from Zephyrus.statistics.models import URL
-from Zephyrus.comment.models import CommentConfig, Comment
 
 register = template.Library()
 
@@ -45,17 +44,12 @@ def viewCount(context, url=None):
     if url:
         if not url.startswith('http'): 
             url = request.build_absolute_uri('/')[:-1].strip("/") + url
-        
-        obj, created = URL.objects.get_or_create(
-            url=url,
-        )
     else:
         url = request.build_absolute_uri(request.path)
-        obj, created = URL.objects.get_or_create(
-            url=url,
-        )
-        obj.viewCount += 1
-        obj.save()
+        
+    obj, created = URL.objects.get_or_create(
+        url=url,
+    )
     
     return obj.viewCount
 
@@ -66,22 +60,8 @@ def commentCount(context, url=None):
     urlObj, created = URL.objects.get_or_create(
         url=url,
     )
-    obj, created = CommentConfig.objects.get_or_create(
-        url=url,
-        defaults={'useFbComment': False},
-    )
-
-    if obj.useFbComment:
-        count = getAPIData(url, "comment_count")
-    else:
-        count = Comment.objects.filter(url=url, display=True).count()
-
-    urlObj.commentCount = count
-    urlObj.save()
-
-    if count:
-        return count
-    return 0
+    
+    return urlObj.commentCount
 
 @register.simple_tag(takes_context=True)
 def likeCount(context, url=None):
@@ -90,12 +70,11 @@ def likeCount(context, url=None):
     urlObj, created = URL.objects.get_or_create(
         url=url,
     )
+    
     count = getAPIData(url, "share_count")
     urlObj.likeCount = count
     urlObj.save()
-
-    if count:
-        return count
-    return 0
+    
+    return urlObj.likeCount
 
     
\ No newline at end of file
